@@ -33,9 +33,9 @@ import (
 	"github.com/stretchr/testify/require"
 	"go.k6.io/k6/js"
 	"go.k6.io/k6/lib"
-	"go.k6.io/k6/lib/metrics"
 	"go.k6.io/k6/lib/testutils"
 	"go.k6.io/k6/loader"
+	"go.k6.io/k6/metrics"
 )
 
 func TestExecutionInfoVUSharing(t *testing.T) {
@@ -88,15 +88,16 @@ func TestExecutionInfoVUSharing(t *testing.T) {
 	registry := metrics.NewRegistry()
 	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
 	runner, err := js.New(
-		logger,
+		&lib.RuntimeState{
+			Logger:         logger,
+			BuiltinMetrics: builtinMetrics,
+			Registry:       registry,
+		},
 		&loader.SourceData{
 			URL:  &url.URL{Path: "/script.js"},
 			Data: script,
 		},
 		nil,
-		lib.RuntimeOptions{},
-		builtinMetrics,
-		registry,
 	)
 	require.NoError(t, err)
 
@@ -117,7 +118,7 @@ func TestExecutionInfoVUSharing(t *testing.T) {
 	}
 
 	errCh := make(chan error, 1)
-	go func() { errCh <- execScheduler.Run(ctx, ctx, samples, builtinMetrics) }()
+	go func() { errCh <- execScheduler.Run(ctx, ctx, samples) }()
 
 	select {
 	case err := <-errCh:
@@ -200,15 +201,16 @@ func TestExecutionInfoScenarioIter(t *testing.T) {
 	registry := metrics.NewRegistry()
 	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
 	runner, err := js.New(
-		logger,
+		&lib.RuntimeState{
+			Logger:         logger,
+			BuiltinMetrics: builtinMetrics,
+			Registry:       registry,
+		},
 		&loader.SourceData{
 			URL:  &url.URL{Path: "/script.js"},
 			Data: script,
 		},
 		nil,
-		lib.RuntimeOptions{},
-		builtinMetrics,
-		registry,
 	)
 	require.NoError(t, err)
 
@@ -216,7 +218,7 @@ func TestExecutionInfoScenarioIter(t *testing.T) {
 	defer cancel()
 
 	errCh := make(chan error, 1)
-	go func() { errCh <- execScheduler.Run(ctx, ctx, samples, builtinMetrics) }()
+	go func() { errCh <- execScheduler.Run(ctx, ctx, samples) }()
 
 	scStats := map[string]uint64{}
 
@@ -281,15 +283,16 @@ func TestSharedIterationsStable(t *testing.T) {
 	registry := metrics.NewRegistry()
 	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
 	runner, err := js.New(
-		logger,
+		&lib.RuntimeState{
+			Logger:         logger,
+			BuiltinMetrics: builtinMetrics,
+			Registry:       registry,
+		},
 		&loader.SourceData{
 			URL:  &url.URL{Path: "/script.js"},
 			Data: script,
 		},
 		nil,
-		lib.RuntimeOptions{},
-		builtinMetrics,
-		registry,
 	)
 	require.NoError(t, err)
 
@@ -297,7 +300,7 @@ func TestSharedIterationsStable(t *testing.T) {
 	defer cancel()
 
 	errCh := make(chan error, 1)
-	go func() { errCh <- execScheduler.Run(ctx, ctx, samples, builtinMetrics) }()
+	go func() { errCh <- execScheduler.Run(ctx, ctx, samples) }()
 
 	expIters := [50]int64{}
 	for i := 0; i < 50; i++ {
@@ -414,17 +417,23 @@ func TestExecutionInfoAll(t *testing.T) {
 
 			registry := metrics.NewRegistry()
 			builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
-			runner, err := js.New(logger, &loader.SourceData{
-				URL:  &url.URL{Path: "/script.js"},
-				Data: []byte(tc.script),
-			}, nil, lib.RuntimeOptions{}, builtinMetrics, registry)
+			runner, err := js.New(
+				&lib.RuntimeState{
+					Logger:         logger,
+					BuiltinMetrics: builtinMetrics,
+					Registry:       registry,
+				},
+				&loader.SourceData{
+					URL:  &url.URL{Path: "/script.js"},
+					Data: []byte(tc.script),
+				}, nil)
 			require.NoError(t, err)
 
 			ctx, cancel, execScheduler, samples := newTestExecutionScheduler(t, runner, logger, lib.Options{})
 			defer cancel()
 
 			errCh := make(chan error, 1)
-			go func() { errCh <- execScheduler.Run(ctx, ctx, samples, builtinMetrics) }()
+			go func() { errCh <- execScheduler.Run(ctx, ctx, samples) }()
 
 			select {
 			case err := <-errCh:
