@@ -31,8 +31,8 @@ import (
 	"go.k6.io/k6/js/common"
 	"go.k6.io/k6/js/modulestest"
 	"go.k6.io/k6/lib"
-	"go.k6.io/k6/lib/metrics"
 	"go.k6.io/k6/lib/netext/httpext"
+	"go.k6.io/k6/metrics"
 )
 
 //nolint: golint, revive
