@@ -39,8 +39,7 @@ import (
 	"go.k6.io/k6/js/common"
 	"go.k6.io/k6/js/modules"
 	httpModule "go.k6.io/k6/js/modules/k6/http"
-	"go.k6.io/k6/lib/metrics"
-	"go.k6.io/k6/stats"
+	"go.k6.io/k6/metrics"
 )
 
 type (
@@ -96,8 +95,8 @@ type Socket struct {
 	pingSendTimestamps map[string]time.Time
 	pingSendCounter    int
 
-	sampleTags     *stats.SampleTags
-	samplesOutput  chan<- stats.SampleContainer
+	sampleTags     *metrics.SampleTags
+	samplesOutput  chan<- metrics.SampleContainer
 	builtinMetrics *metrics.BuiltinMetrics
 }
 
@@ -216,7 +215,7 @@ func (mi *WS) Connect(url string, args ...goja.Value) (*WSHTTPResponse, error) {
 
 	}
 
-	if state.Options.SystemTags.Has(stats.TagURL) {
+	if state.Options.SystemTags.Has(metrics.TagURL) {
 		tags["url"] = url
 	}
 
@@ -244,20 +243,20 @@ func (mi *WS) Connect(url string, args ...goja.Value) (*WSHTTPResponse, error) {
 	start := time.Now()
 	conn, httpResponse, connErr := wsd.DialContext(ctx, url, header)
 	connectionEnd := time.Now()
-	connectionDuration := stats.D(connectionEnd.Sub(start))
+	connectionDuration := metrics.D(connectionEnd.Sub(start))
 
-	if state.Options.SystemTags.Has(stats.TagIP) && conn.RemoteAddr() != nil {
+	if state.Options.SystemTags.Has(metrics.TagIP) && conn.RemoteAddr() != nil {
 		if ip, _, err := net.SplitHostPort(conn.RemoteAddr().String()); err == nil {
 			tags["ip"] = ip
 		}
 	}
 
 	if httpResponse != nil {
-		if state.Options.SystemTags.Has(stats.TagStatus) {
+		if state.Options.SystemTags.Has(metrics.TagStatus) {
 			tags["status"] = strconv.Itoa(httpResponse.StatusCode)
 		}
 
-		if state.Options.SystemTags.Has(stats.TagSubproto) {
+		if state.Options.SystemTags.Has(metrics.TagSubproto) {
 			tags["subproto"] = httpResponse.Header.Get("Sec-WebSocket-Protocol")
 		}
 	}
@@ -271,12 +270,12 @@ func (mi *WS) Connect(url string, args ...goja.Value) (*WSHTTPResponse, error) {
 		scheduled:          make(chan goja.Callable),
 		done:               make(chan struct{}),
 		samplesOutput:      state.Samples,
-		sampleTags:         stats.IntoSampleTags(&tags),
+		sampleTags:         metrics.IntoSampleTags(&tags),
 		builtinMetrics:     state.BuiltinMetrics,
 	}
 
-	stats.PushIfNotDone(ctx, state.Samples, stats.ConnectedSamples{
-		Samples: []stats.Sample{
+	metrics.PushIfNotDone(ctx, state.Samples, metrics.ConnectedSamples{
+		Samples: []metrics.Sample{
 			{Metric: state.BuiltinMetrics.WSSessions, Time: start, Tags: socket.sampleTags, Value: 1},
 			{Metric: state.BuiltinMetrics.WSConnecting, Time: start, Tags: socket.sampleTags, Value: connectionDuration},
 		},
@@ -331,9 +330,9 @@ func (mi *WS) Connect(url string, args ...goja.Value) (*WSHTTPResponse, error) {
 	defer func() {
 		socket.Close() // just in case
 		end := time.Now()
-		sessionDuration := stats.D(end.Sub(start))
+		sessionDuration := metrics.D(end.Sub(start))
 
-		stats.PushIfNotDone(ctx, state.Samples, stats.Sample{
+		metrics.PushIfNotDone(ctx, state.Samples, metrics.Sample{
 			Metric: socket.builtinMetrics.WSSessionDuration,
 			Tags:   socket.sampleTags,
 			Time:   start,
@@ -361,7 +360,7 @@ func (mi *WS) Connect(url string, args ...goja.Value) (*WSHTTPResponse, error) {
 			socket.handleEvent("pong")
 
 		case msg := <-readDataChan:
-			stats.PushIfNotDone(ctx, socket.samplesOutput, stats.Sample{
+			metrics.PushIfNotDone(ctx, socket.samplesOutput, metrics.Sample{
 				Metric: socket.builtinMetrics.WSMessagesReceived,
 				Time:   time.Now(),
 				Tags:   socket.sampleTags,
@@ -421,7 +420,7 @@ func (s *Socket) Send(message string) {
 		s.handleEvent("error", s.rt.ToValue(err))
 	}
 
-	stats.PushIfNotDone(s.ctx, s.samplesOutput, stats.Sample{
+	metrics.PushIfNotDone(s.ctx, s.samplesOutput, metrics.Sample{
 		Metric: s.builtinMetrics.WSMessagesSent,
 		Time:   time.Now(),
 		Tags:   s.sampleTags,
@@ -451,7 +450,7 @@ func (s *Socket) SendBinary(message goja.Value) {
 		common.Throw(s.rt, fmt.Errorf("expected ArrayBuffer as argument, received: %s", jsType))
 	}
 
-	stats.PushIfNotDone(s.ctx, s.samplesOutput, stats.Sample{
+	metrics.PushIfNotDone(s.ctx, s.samplesOutput, metrics.Sample{
 		Metric: s.builtinMetrics.WSMessagesSent,
 		Time:   time.Now(),
 		Tags:   s.sampleTags,
@@ -484,11 +483,11 @@ func (s *Socket) trackPong(pingID string) {
 	}
 	pingTimestamp := s.pingSendTimestamps[pingID]
 
-	stats.PushIfNotDone(s.ctx, s.samplesOutput, stats.Sample{
+	metrics.PushIfNotDone(s.ctx, s.samplesOutput, metrics.Sample{
 		Metric: s.builtinMetrics.WSPing,
 		Time:   pongTimestamp,
 		Tags:   s.sampleTags,
-		Value:  stats.D(pongTimestamp.Sub(pingTimestamp)),
+		Value:  metrics.D(pongTimestamp.Sub(pingTimestamp)),
 	})
 }
 
